@@ -6,7 +6,7 @@
  * Copyright (C) 2001-2002
  *  David Corcoran <corcoran@linuxnet.com>
  *
- * $Id: musclecard.h 1938 2006-03-19 09:55:32Z rousseau $
+ * $Id: musclecard.h 3479 2009-05-01 12:39:59Z rousseau $
  */
 
 #ifndef __musclecard_h__
@@ -854,28 +854,28 @@ extern "C"
 
 	PCSC_API
 	MSC_RV MSCCreateObject(MSCLPTokenConnection pConnection,
-		MSCString objectID,
+		MSCCString objectID,
 		MSCULong32 objectSize, MSCLPObjectACL pObjectACL);
 
 	PCSC_API
 	MSC_RV MSCDeleteObject(MSCLPTokenConnection pConnection,
-		MSCString objectID, MSCUChar8 zeroFlag);
+		MSCCString objectID, MSCUChar8 zeroFlag);
 
 	PCSC_API
 	MSC_RV MSCWriteObject(MSCLPTokenConnection pConnection,
-		MSCString objectID, MSCULong32 offset, 
+		MSCCString objectID, MSCULong32 offset, 
 		MSCPUChar8 pInputData, MSCULong32 dataSize,
 		LPRWEventCallback rwCallback, MSCPVoid32 addParams);
 
 	PCSC_API
 	MSC_RV MSCReadObject(MSCLPTokenConnection pConnection,
-		MSCString objectID, MSCULong32 offset, 
+		MSCCString objectID, MSCULong32 offset, 
                 MSCPUChar8 pOutputData, MSCULong32 dataSize,
 		LPRWEventCallback rwCallback, MSCPVoid32 addParams);
 
 	PCSC_API
 	MSC_RV MSCReadAllocateObject(MSCLPTokenConnection pConnection,
-		MSCString objectID, MSCPUChar8 *pOutputData, 
+		MSCCString objectID, MSCPUChar8 *pOutputData, 
                 MSCPULong32 dataSize,
                 LPRWEventCallback rwCallback, MSCPVoid32 addParams);
 
@@ -911,7 +911,7 @@ extern "C"
 
 	PCSC_API
 	MSC_RV MSCGetObjectAttributes(MSCLPTokenConnection pConnection,
-				      MSCString objectID, 
+				      MSCCString objectID, 
 				      MSCLPObjectInfo pObjectInfo);
 
 	PCSC_API
