@@ -7,7 +7,7 @@
  *  David Corcoran <corcoran@linuxnet.com>
  *  Ludovic Rousseau <ludovic.rousseau@free.fr>
  *
- * $Id: musclecard.c 1966 2006-03-21 16:04:04Z rousseau $
+ * $Id: musclecard.c 3481 2009-05-01 16:25:04Z rousseau $
  */
 
 #include "config.h"
@@ -42,7 +42,7 @@ static ULONG blockingContext = MSC_BLOCKSTATUS_RESUME;
 static SCARDCONTEXT localHContext = 0;
 
 /*
- * internal function 
+ * internal function
  */
 MSC_RV pcscToMSC(MSCLong32);
 MSC_RV MSCReEstablishConnection(MSCLPTokenConnection);
@@ -70,11 +70,11 @@ static void mscUnLockThread(void)
 #pragma fini (musclecard_init)
 #endif
 
-void CONSTRUCTOR musclecard_init(void)
+static void CONSTRUCTOR musclecard_init(void)
 {
 }
 
-void DESTRUCTOR musclecard_fini(void)
+static void DESTRUCTOR musclecard_fini(void)
 {
 	if (localHContext != 0)
 		SCardReleaseContext(localHContext);
@@ -125,7 +125,7 @@ MSC_RV MSCListTokens(MSCULong32 listScope, MSCLPTokenInfo tokenArray,
 	mscUnLockThread();
 
 	/*
-	 * Get the reader list size 
+	 * Get the reader list size
 	 */
 	rv = SCardListReaders(localHContext, NULL, readerList, &readerLength);
 
@@ -140,7 +140,7 @@ MSC_RV MSCListTokens(MSCULong32 listScope, MSCLPTokenInfo tokenArray,
 	rv = SCardListReaders(localHContext, NULL, readerList, &readerLength);
 
 	/*
-	 * Now that we have the readers, lets check their status 
+	 * Now that we have the readers, lets check their status
 	 */
 	for (i = 0; i < readerLength - 1; i++)
 	{
@@ -158,7 +158,7 @@ MSC_RV MSCListTokens(MSCULong32 listScope, MSCLPTokenInfo tokenArray,
 		}
 
 		/*
-		 * We only care about slots with a token unless stated 
+		 * We only care about slots with a token unless stated
 		 */
 		if ((rgReaderStates.dwEventState & SCARD_STATE_PRESENT) ||
 			(listScope == MSC_LIST_SLOTS))
@@ -167,21 +167,21 @@ MSC_RV MSCListTokens(MSCULong32 listScope, MSCLPTokenInfo tokenArray,
 			if (rgReaderStates.dwEventState & SCARD_STATE_PRESENT)
 			{
 				/*
-				 * We only care about supported tokens 
+				 * We only care about supported tokens
 				 */
 				rv = TPSearchBundlesForAtr(rgReaderStates.rgbAtr,
 					rgReaderStates.cbAtr, &tokenInfo);
 			}
 
 			/*
-			 * Success for this function 
+			 * Success for this function
 			 */
 			if ((rv == 0) || (listScope == MSC_LIST_SLOTS) ||
 				(listScope == MSC_LIST_ALL))
 			{
 
 				/*
-				 * We found something interesting to the application 
+				 * We found something interesting to the application
 				 */
 				tokensFound += 1;
 
@@ -245,11 +245,11 @@ MSC_RV MSCListTokens(MSCULong32 listScope, MSCLPTokenInfo tokenArray,
 				}
 			}
 			/*
-			 * End of TPSearch success 
+			 * End of TPSearch success
 			 */
 		}
 		/*
-		 * End of if token present 
+		 * End of if token present
 		 */
 		while (readerList[++i] != 0);
 	}	/* End of for .. readers */
@@ -258,7 +258,7 @@ MSC_RV MSCListTokens(MSCULong32 listScope, MSCLPTokenInfo tokenArray,
 		free(readerList);
 
 	/*
-	 * Application provides null requesting length 
+	 * Application provides null requesting length
 	 */
 	if (tokenArray == NULL)
 	{
@@ -267,7 +267,7 @@ MSC_RV MSCListTokens(MSCULong32 listScope, MSCLPTokenInfo tokenArray,
 	}
 
 	/*
-	 * Provided length is too small 
+	 * Provided length is too small
 	 */
 	if (*arrayLength < tokensFound)
 	{
@@ -323,7 +323,7 @@ MSC_RV MSCEstablishConnection(MSCLPTokenInfo tokenStruct,
 	pConnection->shareMode = 0;
 
 	/*
-	 * Check the token name strings 
+	 * Check the token name strings
 	 */
 	if (sharingMode != MSC_SHARE_DIRECT)
 	{
@@ -335,7 +335,7 @@ MSC_RV MSCEstablishConnection(MSCLPTokenInfo tokenStruct,
 	}
 
 	/*
-	 * Set up the initial connection to the resource manager 
+	 * Set up the initial connection to the resource manager
 	 */
 
 	mscLockThread();
@@ -380,7 +380,7 @@ MSC_RV MSCEstablishConnection(MSCLPTokenInfo tokenStruct,
 	pConnection->shareMode = sharingMode;
 
 	/*
-	 * Set the sendPCI value based on the ActiveProtocol 
+	 * Set the sendPCI value based on the ActiveProtocol
 	 */
 	switch (dwActiveProtocol)
 	{
@@ -396,8 +396,8 @@ MSC_RV MSCEstablishConnection(MSCLPTokenInfo tokenStruct,
 	}
 
 	/*
-	 * Call SCardStatus, make sure the card information matches if it does 
-	 * not return an error.  If it does, copy it 
+	 * Call SCardStatus, make sure the card information matches if it does
+	 * not return an error.  If it does, copy it
 	 */
 
 	rv = SCardStatus(pConnection->hCard, slotName,
@@ -418,7 +418,7 @@ MSC_RV MSCEstablishConnection(MSCLPTokenInfo tokenStruct,
 	{
 		/*
 		 * They asked for direct mode and no card is inserted so we are
-		 * done with this 
+		 * done with this
 		 */
 		return MSC_SUCCESS;
 	}
@@ -441,7 +441,7 @@ MSC_RV MSCEstablishConnection(MSCLPTokenInfo tokenStruct,
 		MSC_MAXSIZE_TOKENAME);
 
 	/*
-	 * Load the library for the token 
+	 * Load the library for the token
 	 */
 	rv = TPLoadToken(pConnection);
 
@@ -457,7 +457,7 @@ MSC_RV MSCEstablishConnection(MSCLPTokenInfo tokenStruct,
 	}
 
 	/*
-	 * Select the AID or initialization routine for the card 
+	 * Select the AID or initialization routine for the card
 	 */
 	vInitFunction = pConnection->libPointers.pvfInitializePlugin;
 	vIdFunction = pConnection->libPointers.pvfIdentifyToken;
@@ -505,7 +505,7 @@ MSC_RV MSCEstablishConnection(MSCLPTokenInfo tokenStruct,
 		if ((applicationName == 0) || (nameSize == 0))
 		{
 			/*
-			 * Use the default AID given by the Info.plist 
+			 * Use the default AID given by the Info.plist
 			 */
 
 			rv = (*libPL_MSCIdentifyToken) (pConnection);
@@ -562,7 +562,7 @@ MSC_RV MSCReleaseConnection(MSCLPTokenConnection pConnection,
 	}
 
 	/*
-	 * Select finalization routine for the token plugin 
+	 * Select finalization routine for the token plugin
 	 */
 	vFunction = pConnection->libPointers.pvfFinalizePlugin;
 
@@ -576,12 +576,12 @@ MSC_RV MSCReleaseConnection(MSCLPTokenConnection pConnection,
 	libPL_MSCFinalizePlugin = (MSCLong32(*)(MSCLPTokenConnection)) vFunction;
 
 	/*
-	 * Stop and clean up the plugin 
+	 * Stop and clean up the plugin
 	 */
 	rv = (*libPL_MSCFinalizePlugin) (pConnection);
 
 	/*
-	 * Disconnect from the token 
+	 * Disconnect from the token
 	 */
 	if (pConnection->hCard != 0)
 	{
@@ -591,7 +591,7 @@ MSC_RV MSCReleaseConnection(MSCLPTokenConnection pConnection,
 	}
 
 	/*
-	 * Unload the token driver 
+	 * Unload the token driver
 	 */
 	if (pConnection->tokenLibHandle != 0)
 	{
@@ -599,16 +599,6 @@ MSC_RV MSCReleaseConnection(MSCLPTokenConnection pConnection,
 		pConnection->tokenLibHandle = 0;
 	}
 
-	/*
-	 * Release Context
-	 */
-	if (pConnection->hContext != 0)
-	{
-		rv = SCardReleaseContext(pConnection->hContext);
-		if (pcscToMSC(rv) != MSC_SUCCESS)
-			return pcscToMSC(rv);
-	}
-
 	pConnection->tokenLibHandle = 0;
 	pConnection->hCard = 0;
 	pConnection->hContext = 0;
@@ -630,7 +620,7 @@ MSC_RV MSCWaitForTokenEvent(MSCLPTokenInfo tokenArray,
 	/*
 	 * Allocate array of SCARD_READERSTATE_A structures, set UNAWARE on
 	 * all of the structures to get the current status and then send them
-	 * to GetStatusChange for blocking event 
+	 * to GetStatusChange for blocking event
 	 */
 
 	if (arraySize == 0)
@@ -640,7 +630,7 @@ MSC_RV MSCWaitForTokenEvent(MSCLPTokenInfo tokenArray,
 			return MSC_INSUFFICIENT_BUFFER;
 
 	/*
-	 * Set up the initial connection to the resource manager 
+	 * Set up the initial connection to the resource manager
 	 */
 
 	mscLockThread();
@@ -665,7 +655,7 @@ MSC_RV MSCWaitForTokenEvent(MSCLPTokenInfo tokenArray,
 	for (i = 0; i < arraySize; i++)
 	{
 		/*
-		 * Make sure they don't pass an empty structure 
+		 * Make sure they don't pass an empty structure
 		 */
 		if (strlen(tokenArray[i].slotName) == 0)
 		{
@@ -710,7 +700,7 @@ MSC_RV MSCWaitForTokenEvent(MSCLPTokenInfo tokenArray,
 		if (tokenArray[i].tokenState & MSC_STATE_CHANGED)
 		{
 			/*
-			 * If it is removed, we need to update the names/etc 
+			 * If it is removed, we need to update the names/etc
 			 */
 			if (tokenArray[i].tokenState & MSC_STATE_EMPTY)
 			{
@@ -729,7 +719,7 @@ MSC_RV MSCWaitForTokenEvent(MSCLPTokenInfo tokenArray,
 				rt = TPSearchBundlesForAtr(rgReaderStates[i].rgbAtr,
 					rgReaderStates[i].cbAtr, &tokenInfo);
 				/*
-				 * Successfully found 
+				 * Successfully found
 				 */
 				if (rt == 0)
 				{
@@ -762,7 +752,7 @@ MSC_RV MSCCancelEventWait(void)
 
 /************************ Start of Callbacks ****************************/
 #ifdef USE_THREAD_SAFETY
-void *_MSCEventThread(void *arg)
+static void *_MSCEventThread(void *arg)
 {
 	MSCLong32 rv;
 	MSCLPEventWaitInfo evlist;
@@ -809,7 +799,7 @@ MSC_RV MSCCallbackForTokenEvent(MSCLPTokenInfo tokenArray,
 	MSCULong32 curToken;
 
 	/*
-	 * Create the event wait list 
+	 * Create the event wait list
 	 */
 	evlist = (MSCLPEventWaitInfo) malloc(sizeof(MSCEventWaitInfo));
 
@@ -831,7 +821,7 @@ MSC_RV MSCCallbackForTokenEvent(MSCLPTokenInfo tokenArray,
 	memcpy(evlist->tokenArray, tokenArray, sizeof(MSCTokenInfo) * arraySize);
 
 	/*
-	 * Copy the "extra" data 
+	 * Copy the "extra" data
 	 */
 	for (curToken = 0; curToken < arraySize; curToken++)
 	{
@@ -863,8 +853,7 @@ MSC_RV MSCCallbackCancelEvent(void)
 		blockingContext = MSC_BLOCKSTATUS_CANCELLING;
 		rv = MSCCancelEventWait();
 
-		SYS_ThreadJoin(&callbackThread, 0);
-
+		SYS_ThreadJoin(callbackThread, 0);
 	}
 
 	return MSC_SUCCESS;
@@ -969,7 +958,7 @@ MSC_RV MSCWriteFramework(MSCLPTokenConnection pConnection,
 }
 
 /*
- * Real MSC functions 
+ * Real MSC functions
  */
 
 MSC_RV MSCGetStatus(MSCLPTokenConnection pConnection,
@@ -1393,12 +1382,12 @@ MSC_RV MSCListPINs(MSCLPTokenConnection pConnection, MSCPUShort16 pPinBitMask)
 }
 
 MSC_RV MSCCreateObject(MSCLPTokenConnection pConnection,
-	MSCString objectID, MSCULong32 objectSize, MSCLPObjectACL pObjectACL)
+	MSCCString objectID, MSCULong32 objectSize, MSCLPObjectACL pObjectACL)
 {
 	MSCLong32 rv;
 	MSCPVoid32 vFunction;
 
-	MSCLong32(*libMSCCreateObject) (MSCLPTokenConnection, MSCString,
+	MSCLong32(*libMSCCreateObject) (MSCLPTokenConnection, MSCCString,
 		MSCULong32, MSCLPObjectACL);
 
 	if (pConnection == NULL)
@@ -1410,7 +1399,7 @@ MSC_RV MSCCreateObject(MSCLPTokenConnection pConnection,
 
 	if (vFunction != NULL)
 	{
-		libMSCCreateObject = (MSCLong32(*)(MSCLPTokenConnection, MSCString,
+		libMSCCreateObject = (MSCLong32(*)(MSCLPTokenConnection, MSCCString,
 				MSCULong32, MSCLPObjectACL)) vFunction;
 		rv = (*libMSCCreateObject) (pConnection, objectID, objectSize,
 			pObjectACL);
@@ -1422,12 +1411,12 @@ MSC_RV MSCCreateObject(MSCLPTokenConnection pConnection,
 }
 
 MSC_RV MSCDeleteObject(MSCLPTokenConnection pConnection,
-	MSCString objectID, MSCUChar8 zeroFlag)
+	MSCCString objectID, MSCUChar8 zeroFlag)
 {
 	MSCLong32 rv;
 	MSCPVoid32 vFunction;
 
-	MSCLong32(*libMSCDeleteObject) (MSCLPTokenConnection, MSCString,
+	MSCLong32(*libMSCDeleteObject) (MSCLPTokenConnection, MSCCString,
 		MSCUChar8);
 
 	if (pConnection == NULL)
@@ -1439,7 +1428,7 @@ MSC_RV MSCDeleteObject(MSCLPTokenConnection pConnection,
 
 	if (vFunction != NULL)
 	{
-		libMSCDeleteObject = (MSCLong32(*)(MSCLPTokenConnection, MSCString,
+		libMSCDeleteObject = (MSCLong32(*)(MSCLPTokenConnection, MSCCString,
 				MSCUChar8)) vFunction;
 		rv = (*libMSCDeleteObject) (pConnection, objectID, zeroFlag);
 	}
@@ -1450,7 +1439,7 @@ MSC_RV MSCDeleteObject(MSCLPTokenConnection pConnection,
 }
 
 MSC_RV MSCWriteObject(MSCLPTokenConnection pConnection,
-	MSCString objectID, MSCULong32 offSet,
+	MSCCString objectID, MSCULong32 offSet,
 	MSCPUChar8 pInputData, MSCULong32 dataSize,
 	LPRWEventCallback rwCallback, MSCPVoid32 addParams)
 {
@@ -1461,7 +1450,7 @@ MSC_RV MSCWriteObject(MSCLPTokenConnection pConnection,
 	MSC_RV(*callBackFunction) (void *, int);
 	MSCPVoid32 vFunction;
 
-	MSCLong32(*libMSCWriteObject) (MSCLPTokenConnection, MSCString,
+	MSCLong32(*libMSCWriteObject) (MSCLPTokenConnection, MSCCString,
 		MSCULong32, MSCPUChar8, MSCUChar8);
 	int i;
 
@@ -1477,12 +1466,12 @@ MSC_RV MSCWriteObject(MSCLPTokenConnection pConnection,
 	if (vFunction == NULL)
 		return MSC_UNSUPPORTED_FEATURE;
 
-	libMSCWriteObject = (MSCLong32(*)(MSCLPTokenConnection, MSCString,
+	libMSCWriteObject = (MSCLong32(*)(MSCLPTokenConnection, MSCCString,
 			MSCULong32, MSCPUChar8, MSCUChar8)) vFunction;
 
 	/*
 	 * Figure out the number of steps total and present this in a percent
-	 * step basis 
+	 * step basis
 	 */
 
 	totalSteps = objectSize / MSC_SIZEOF_KEYPACKET + 1;
@@ -1522,7 +1511,7 @@ MSC_RV MSCWriteObject(MSCLPTokenConnection pConnection,
 }
 
 MSC_RV MSCReadObject(MSCLPTokenConnection pConnection,
-	MSCString objectID, MSCULong32 offSet,
+	MSCCString objectID, MSCULong32 offSet,
 	MSCPUChar8 pOutputData, MSCULong32 dataSize,
 	LPRWEventCallback rwCallback, MSCPVoid32 addParams)
 {
@@ -1533,7 +1522,7 @@ MSC_RV MSCReadObject(MSCLPTokenConnection pConnection,
 	MSC_RV(*callBackFunction) (void *, int);
 	MSCPVoid32 vFunction;
 
-	MSCLong32(*libMSCReadObject) (MSCLPTokenConnection, MSCString,
+	MSCLong32(*libMSCReadObject) (MSCLPTokenConnection, MSCCString,
 		MSCULong32, MSCPUChar8, MSCUChar8);
 	int i;
 
@@ -1550,11 +1539,11 @@ MSC_RV MSCReadObject(MSCLPTokenConnection pConnection,
 		return MSC_UNSUPPORTED_FEATURE;
 
 	libMSCReadObject = (MSCLong32(*)(MSCLPTokenConnection,
-			MSCString, MSCULong32, MSCPUChar8, MSCUChar8)) vFunction;
+			MSCCString, MSCULong32, MSCPUChar8, MSCUChar8)) vFunction;
 
 	/*
 	 * Figure out the number of steps total and present this in a percent
-	 * step basis 
+	 * step basis
 	 */
 
 	totalSteps = objectSize / MSC_SIZEOF_KEYPACKET + 1;
@@ -1743,7 +1732,7 @@ MSC_RV MSCGetKeyAttributes(MSCLPTokenConnection pConnection,
 }
 
 MSC_RV MSCGetObjectAttributes(MSCLPTokenConnection pConnection,
-	MSCString objectID, MSCLPObjectInfo pObjectInfo)
+	MSCCString objectID, MSCLPObjectInfo pObjectInfo)
 {
 	MSC_RV rv;
 	MSCObjectInfo objInfo;
@@ -1800,14 +1789,14 @@ MSC_RV MSCGetObjectAttributes(MSCLPTokenConnection pConnection,
 }
 
 MSC_RV MSCReadAllocateObject(MSCLPTokenConnection pConnection,
-	MSCString objectID, MSCPUChar8 * pOutputData,
+	MSCCString objectID, MSCPUChar8 * pOutputData,
 	MSCPULong32 dataSize, LPRWEventCallback rwCallback, MSCPVoid32 addParams)
 {
     MSC_RV rv;
     MSCObjectInfo objInfo;
     MSCULong32 objectSize;
     MSCPUChar8  data = NULL;
-    
+
     if (pConnection == NULL)
         return MSC_INVALID_PARAMETER;
      if (localHContext == 0)
@@ -1822,7 +1811,7 @@ MSC_RV MSCReadAllocateObject(MSCLPTokenConnection pConnection,
     *pOutputData = 0;
 
     rv = MSCGetObjectAttributes(pConnection, objectID, &objInfo);
-    if (rv == MSC_SUCCESS) 
+    if (rv == MSC_SUCCESS)
     {
         objectSize = objInfo.objectSize;
         data = (MSCPUChar8) malloc(sizeof(MSCUChar8) * objectSize);
@@ -1830,7 +1819,7 @@ MSC_RV MSCReadAllocateObject(MSCLPTokenConnection pConnection,
         {
             rv =  MSCReadObject(pConnection, objectID, 0, data,
                      objectSize, rwCallback, addParams);
-            
+
             if (rv == MSC_SUCCESS)
             {
                 *dataSize = objectSize;
@@ -2008,7 +1997,7 @@ MSC_RV MSCReEstablishConnection(MSCLPTokenConnection pConnection)
 	vIdFunction = NULL;
 
 	/*
-	 * Select the AID or initialization routine for the card 
+	 * Select the AID or initialization routine for the card
 	 */
 	vInitFunction = pConnection->libPointers.pvfInitializePlugin;
 	vFinFunction = pConnection->libPointers.pvfFinalizePlugin;
@@ -2051,17 +2040,17 @@ MSC_RV MSCReEstablishConnection(MSCLPTokenConnection pConnection)
 		return pcscToMSC(rv);
 
 	/*
-	 * Stop the plugin and start it up again 
+	 * Stop the plugin and start it up again
 	 */
 	rv = (*libPL_MSCFinalizePlugin) (pConnection);
 
 	/*
-	 * Use the default AID given by the Info.plist 
+	 * Use the default AID given by the Info.plist
 	 */
 	rv = (*libPL_MSCInitializePlugin) (pConnection);
 
-	/* 
-	 * Use the default AID given by the Info.plist 
+	/*
+	 * Use the default AID given by the Info.plist
 	 */
 	rv = (*libPL_MSCIdentifyToken) (pConnection);
 
@@ -2138,4 +2127,3 @@ MSCUChar8 MSCIsTokenKnown(MSCLPTokenConnection pConnection)
 	else
 		return 0;
 }
-
