@@ -5,7 +5,7 @@
  *  Toni Andjelkovic <toni@soth.at>
  *  Ludovic Rousseau <ludovic.rousseau@free.fr>
  *
- * $Id: parser.h 2010 2006-04-18 14:00:59Z rousseau $
+ * $Id: parser.h 3260 2009-01-02 15:19:59Z rousseau $
  */
 
 /**
@@ -27,8 +27,8 @@ extern "C"
 #define TOKEN_TYPE_KEY         1
 #define TOKEN_TYPE_STRING      2
 
-int LTPBundleFindValueWithKey(char *fileName, char *tokenKey,
-                              char *tokenValue, int tokenIndice);
+int LTPBundleFindValueWithKey(const char *fileName, const char *tokenKey,
+                              /*@out@*/ char *tokenValue, int tokenIndice);
 
 #ifdef __cplusplus
 }
