@@ -8,7 +8,7 @@
  * Copyright (C) 2004
  *  Ludovic Rousseau <ludovic.rousseau@free.fr>
  *
- * $Id: tokenfactory.c 1966 2006-03-21 16:04:04Z rousseau $
+ * $Id: tokenfactory.c 3476 2009-05-01 12:25:52Z rousseau $
  */
 
 #include "config.h"
@@ -42,7 +42,7 @@
 #define MSC_LIBRMSC_KEY_NAME                "CFBundleExecutable"
 #define MSC_DEFAULTAPP_NAME                 "spDefaultApplication"
 
-int atrToString(MSCPUChar8 Atr, MSCULong32 Length, char *outAtr)
+static int atrToString(MSCPUChar8 Atr, MSCULong32 Length, char *outAtr)
 {
 	MSCULong32 i;
 	MSCULong32 j;
@@ -78,7 +78,7 @@ int atrToString(MSCPUChar8 Atr, MSCULong32 Length, char *outAtr)
 	return 0;
 }
 
-int stringToBytes(char *inStr, MSCPUChar8 Buffer, MSCPULong32 Length)
+static int stringToBytes(char *inStr, MSCPUChar8 Buffer, MSCPULong32 Length)
 {
 	int i;
 	int j;
